aboutsummaryrefslogtreecommitdiff
path: root/src/qt/bitcoingui.cpp
diff options
context:
space:
mode:
authorTomo Ueda <[email protected]>2021-09-02 12:55:18 -0700
committerTomo Ueda <[email protected]>2021-09-02 12:55:18 -0700
commite64843ced509c24f783276d4cc0f2f26c9d527f2 (patch)
tree7956d4ea416c5b3a531dbc6f356e1c9a643d9690 /src/qt/bitcoingui.cpp
parentreally s/doge/dis/g this time (diff)
downloadarchived-discoin-e64843ced509c24f783276d4cc0f2f26c9d527f2.tar.xz
archived-discoin-e64843ced509c24f783276d4cc0f2f26c9d527f2.zip
really s/Doge/Dis/g this time
Diffstat (limited to 'src/qt/bitcoingui.cpp')
-rw-r--r--src/qt/bitcoingui.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/qt/bitcoingui.cpp b/src/qt/bitcoingui.cpp
index d92bf7c93..ae7e9a5ba 100644
--- a/src/qt/bitcoingui.cpp
+++ b/src/qt/bitcoingui.cpp
@@ -171,7 +171,7 @@ BitcoinGUI::BitcoinGUI(const PlatformStyle *_platformStyle, const NetworkStyle *
setCentralWidget(rpcConsole);
}
// Dogecoin: load fallback font in case Comic Sans is not available on the system
QFontDatabase::addApplicationFont(":fonts/ComicNeue-Bold");
QFontDatabase::addApplicationFont(":fonts/ComicNeue-Bold-Oblique");
QFontDatabase::addApplicationFont(":fonts/ComicNeue-Light");
@@ -180,10 +180,10 @@ BitcoinGUI::BitcoinGUI(const PlatformStyle *_platformStyle, const NetworkStyle *
QFontDatabase::addApplicationFont(":fonts/ComicNeue-Regular-Oblique");
QFont::insertSubstitution("Comic Sans MS", "Comic Neue");
// Dogecoin: Specify Comic Sans as new font.
QFont newFont("Comic Sans MS", 10);
// Dogecoin: Set new application font
QApplication::setFont(newFont);
// Accept D&D of URIs
@@ -303,7 +303,7 @@ void BitcoinGUI::createActions()
tabGroup->addAction(overviewAction);
sendCoinsAction = new QAction(platformStyle->SingleColorIcon(":/icons/send"), tr("&Such Send"), this);
- sendCoinsAction->setStatusTip(tr("Send coins to a Dogecoin address"));
+ sendCoinsAction->setStatusTip(tr("Send coins to a Discoin address"));
sendCoinsAction->setToolTip(sendCoinsAction->statusTip());
sendCoinsAction->setCheckable(true);
sendCoinsAction->setShortcut(QKeySequence(Qt::ALT + Qt::Key_2));
@@ -374,9 +374,9 @@ void BitcoinGUI::createActions()
changePassphraseAction = new QAction(platformStyle->TextColorIcon(":/icons/key"), tr("&Change Passphrase..."), this);
changePassphraseAction->setStatusTip(tr("Change the passphrase used for wallet encryption"));
signMessageAction = new QAction(platformStyle->TextColorIcon(":/icons/edit"), tr("Sign &message..."), this);
- signMessageAction->setStatusTip(tr("Sign messages with your Dogecoin addresses to prove you own them"));
+ signMessageAction->setStatusTip(tr("Sign messages with your Discoin addresses to prove you own them"));
verifyMessageAction = new QAction(platformStyle->TextColorIcon(":/icons/verify"), tr("&Verify message..."), this);
- verifyMessageAction->setStatusTip(tr("Verify messages to ensure they were signed with specified Dogecoin addresses"));
+ verifyMessageAction->setStatusTip(tr("Verify messages to ensure they were signed with specified Discoin addresses"));
paperWalletAction = new QAction(QIcon(":/icons/print"), tr("&Print paper wallets"), this);
paperWalletAction->setStatusTip(tr("Print paper wallets"));
@@ -394,11 +394,11 @@ void BitcoinGUI::createActions()
openAction->setStatusTip(tr("Open a discoin: URI or payment request"));
importPrivateKeyAction = new QAction(platformStyle->TextColorIcon(":/icons/address-book"), tr("&Import Private Key..."), this);
- importPrivateKeyAction->setStatusTip(tr("Import a Dogecoin private key"));
+ importPrivateKeyAction->setStatusTip(tr("Import a Discoin private key"));
showHelpMessageAction = new QAction(platformStyle->TextColorIcon(":/icons/info"), tr("&Command-line options"), this);
showHelpMessageAction->setMenuRole(QAction::NoRole);
- showHelpMessageAction->setStatusTip(tr("Show the %1 help message to get a list with possible Dogecoin command-line options").arg(tr(PACKAGE_NAME)));
+ showHelpMessageAction->setStatusTip(tr("Show the %1 help message to get a list with possible Discoin command-line options").arg(tr(PACKAGE_NAME)));
connect(quitAction, SIGNAL(triggered()), qApp, SLOT(quit()));
connect(aboutAction, SIGNAL(triggered()), this, SLOT(aboutClicked()));
@@ -757,7 +757,7 @@ void BitcoinGUI::updateNetworkState()
QString tooltip;
if (clientModel->getNetworkActive()) {
- tooltip = tr("%n active connection(s) to Dogecoin network", "", count) + QString(".<br>") + tr("Click to disable network activity.");
+ tooltip = tr("%n active connection(s) to Discoin network", "", count) + QString(".<br>") + tr("Click to disable network activity.");
} else {
tooltip = tr("Network activity disabled.") + QString("<br>") + tr("Click to enable network activity again.");
icon = ":/icons/network_disabled";
@@ -901,7 +901,7 @@ void BitcoinGUI::setNumBlocks(int count, const QDateTime& blockDate, double nVer
void BitcoinGUI::message(const QString &title, const QString &message, unsigned int style, bool *ret)
{
- QString strTitle = tr("Dogecoin"); // default title
+ QString strTitle = tr("Discoin"); // default title
// Default to information icon
int nMBoxIcon = QMessageBox::Information;
int nNotifyIcon = Notificator::Information;
@@ -171,7 +171,7 @@ BitcoinGUI::BitcoinGUI(const PlatformStyle *_platformStyle, const NetworkStyle *
setCentralWidget(rpcConsole);
}
- // Dogecoin: load fallback font in case Comic Sans is not available on the system
+ // Discoin: load fallback font in case Comic Sans is not available on the system
QFontDatabase::addApplicationFont(":fonts/ComicNeue-Bold");
QFontDatabase::addApplicationFont(":fonts/ComicNeue-Bold-Oblique");
@@ -180,10 +180,10 @@ BitcoinGUI::BitcoinGUI(const PlatformStyle *_platformStyle, const NetworkStyle *
QFontDatabase::addApplicationFont(":fonts/ComicNeue-Regular-Oblique");
QFont::insertSubstitution("Comic Sans MS", "Comic Neue");
- // Dogecoin: Specify Comic Sans as new font.
+ // Discoin: Specify Comic Sans as new font.
QFont newFont("Comic Sans MS", 10);
@@ -180,10 +180,10 @@ BitcoinGUI::BitcoinGUI(const PlatformStyle *_platformStyle, const NetworkStyle *
QFont newFont("Comic Sans MS", 10);
- // Dogecoin: Set new application font
+ // Discoin: Set new application font
QApplication::setFont(newFont);
// Accept D&D of URIs